/*
 * Sonar, open source software quality management tool.
 * Copyright (C) 2009 SonarSource SA
 * mailto:contact AT sonarsource DOT com
 *
 * Sonar is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * Sonar is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sonar; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02
 */
package org.sonar.updatecenter.server;

import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.sonar.updatecenter.*;

import java.io.File;
import java.io.IOException;
import java.net.URISyntaxException;

public final class Server {
  private static Logger LOG = LoggerFactory.getLogger(Server.class);

  public void start() throws IOException, URISyntaxException {
    Configuration conf = new Configuration(System.getProperties());
    Downloader downloader = new Downloader(conf.getWorkingDir());
    File sourceFile = downloader.download(conf.getSourceUrl(), true);

    UpdateCenter center = UpdateCenterDeserializer.fromProperties(sourceFile);
    for (Plugin plugin : center.getPlugins()) {
      LOG.info("Load plugin: " + plugin.getKey());
      Release lastRelease = plugin.getLastRelease();
      if (lastRelease != null) {
        if (StringUtils.isNotBlank(lastRelease.getDownloadUrl())) {
          File jar = downloader.download(lastRelease.getDownloadUrl(), false);
          plugin.merge(new PluginManifest(jar));

        } else {
          LOG.warn("Missing downloadUrl: plugin " + plugin.getKey() + ", version " + lastRelease.getVersion());
        }
      }
    }

    LOG.info("Generate output: " + conf.getOutputFile());
    UpdateCenterSerializer.toProperties(center, conf.getOutputFile());
  }

  public static void main(String[] args) throws IOException, URISyntaxException {
    new Server().start();
  }

}
